@@ -148,7 +148,7 @@ namespace anyks {
 		 */
 		const wstring getEmail() noexcept {
 			// Выводим результат
-			return alphabet.convert(ANYKS_EMAIL);
+			return alphabet.convert(ANYKS_LM_EMAIL);
 		}
 		/**
 		 * getPhone Метод извлечения телефона автора
@@ -156,7 +156,7 @@ namespace anyks {
 		 */
 		const wstring getPhone() noexcept {
 			// Выводим результат
-			return alphabet.convert(ANYKS_PHONE);
+			return alphabet.convert(ANYKS_LM_PHONE);
 		}
 		/**
 		 * getAuthor Метод извлечения имени автора
@@ -164,7 +164,7 @@ namespace anyks {
 		 */
 		const wstring getAuthor() noexcept {
 			// Выводим результат
-			return alphabet.convert(ANYKS_AUTHOR);
+			return alphabet.convert(ANYKS_LM_AUTHOR);
 		}
 		/**
 		 * findNgram Метод поиска n-грамм в тексте
@@ -372,7 +372,7 @@ namespace anyks {
 		 */
 		const wstring getContact() noexcept {
 			// Выводим результат
-			return alphabet.convert(ANYKS_CONTACT);
+			return alphabet.convert(ANYKS_LM_CONTACT);
 		}
 		/**
 		 * getUppers Метод извлечения регистров для каждого слова
@@ -393,7 +393,7 @@ namespace anyks {
 		 */
 		const wstring getSite() noexcept {
 			// Выводим результат
-			return alphabet.convert(ANYKS_SITE);
+			return alphabet.convert(ANYKS_LM_SITE);
 		}
 		/**
 		 * getAlphabet Метод получения алфавита языка
@@ -426,7 +426,7 @@ namespace anyks {
 		 */
 		const wstring getVersion() noexcept {
 			// Выводим результат
-			return alphabet.convert(ANYKS_VERSION);
+			return alphabet.convert(ANYKS_LM_VERSION);
 		}
 		/**
 		 * isAllowApostrophe Метод проверки разрешения апострофа
@@ -1022,12 +1022,12 @@ namespace anyks {
 			return alm.pplByFiles(alphabet.convert(path), nullptr, alphabet.convert(ext));
 		}
 		/**
-		 * delInWord Метод очистки текста
+		 * delInText Метод очистки текста
 		 * @param text текст для очистки
 		 * @param flag флаг критерия очистки
 		 * @return     текст без запрещенных символов
 		 */
-		const wstring delInWord(const wstring & text, const wdel_t flag = wdel_t::broken) noexcept {
+		const wstring delInText(const wstring & text, const wdel_t flag = wdel_t::broken) noexcept {
 			// Выполняем проверку флага
 			switch(u_short(flag)){
 				// Выполняем удаление знаков пунктуации в тексте
@@ -1340,8 +1340,8 @@ PYBIND11_MODULE(alm, m) {
 		.def("sentencesToFile", &anyks::Methods::sentencesToFile, "Method for assembling a specified number of sentences and writing to a file", py::arg("counts") = 0, py::arg("filename") = L"")
 		// fixUppersByFiles Метод исправления регистров текста в текстовом файле
 		.def("fixUppersByFiles", &anyks::Methods::fixUppersByFiles, "Method for correcting text registers in a text file", py::arg("path") = L"", py::arg("filename") = L"", py::arg("ext") = L"txt")
-		// delInWord Метод очистки текста
-		.def("delInWord", overload_cast_ <const wstring &, const anyks::wdel_t> ()(&anyks::Methods::delInWord), "Method for delete letter in word", py::arg("text") = L"", py::arg("flag") = anyks::wdel_t::broken)
+		// delInText Метод очистки текста
+		.def("delInText", overload_cast_ <const wstring &, const anyks::wdel_t> ()(&anyks::Methods::delInText), "Method for delete letter in text", py::arg("text") = L"", py::arg("flag") = anyks::wdel_t::broken)
 		// checkSequence Метод проверки существования последовательности
 		.def("checkSequence", overload_cast_ <const vector <size_t> &, const bool> ()(&anyks::Methods::checkSequence), "Sequence Existence Method", py::arg("seq") = vector <size_t> (), py::arg("accurate") = false)
 		// countsByFiles Метод подсчёта количества n-грамм в текстовом файле
